==> opensearch-dashboards-2.11.1.tgz: opensearch-dashboards/src/plugins/home/server/services/tutorials/lib/tutorials_registry_types.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TutorialsCategory = void 0;

/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/** @public */
let TutorialsCategory;
exports.TutorialsCategory = TutorialsCategory;

(function (TutorialsCategory) {
  TutorialsCategory["LOGGING"] = "logging";
  TutorialsCategory["SECURITY_SOLUTION"] = "security";
  TutorialsCategory["METRICS"] = "metrics";
  TutorialsCategory["OTHER"] = "other";
})(TutorialsCategory || (exports.TutorialsCategory = TutorialsCategory = {}));

==> opensearch-dashboards-2.16.0.tgz: opensearch-dashboards/src/plugins/home/server/services/tutorials/lib/tutorials_registry_types.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TutorialsCategory = void 0;
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/** @public */
let TutorialsCategory = exports.TutorialsCategory = /*#__PURE__*/function (TutorialsCategory) {
  TutorialsCategory["LOGGING"] = "logging";
  TutorialsCategory["SECURITY_SOLUTION"] = "security";
  TutorialsCategory["METRICS"] = "metrics";
  TutorialsCategory["OTHER"] = "other";
  return TutorialsCategory;
}({});
